"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("../average");
require("../chunkByCount");
const customErrors_1 = require("../utils/customErrors");
Array.prototype.chunkBySize = function (chunkSize, forceFairness = false, treatChunkSizeAsMax = false, thisArg = this) {
    if (chunkSize <= 0)
        throw new customErrors_1.Exception_OutOfBounds();
    const result = [];
    if (forceFairness) {
        const calculatedChunkCount = thisArg.length / chunkSize;
        if (thisArg.length % chunkSize == 0)
            return thisArg.chunkByCount(calculatedChunkCount);
        if (treatChunkSizeAsMax)
            return thisArg.chunkByCount(Math.ceil(calculatedChunkCount));
        // If the array's size can't be evenly divided into the chunkSize we aim to find the best match.
        //chunk the array into the lower & upper bound.
        // E.G.The array's length is 10 and chunk size is 3, the lower is 3 chunks the upper is 4.
        const lowerChunkCount = thisArg.chunkByCount(Math.floor(calculatedChunkCount));
        const upperChunkCount = thisArg.chunkByCount(Math.ceil(calculatedChunkCount));
        //The average size each chunk has from the wanted chunkSize
        const lowerChunkDiff = lowerChunkCount.map(arr => Math.abs(arr.length - chunkSize)).average();
        const upperChunkDiff = upperChunkCount.map(arr => Math.abs(arr.length - chunkSize)).average();
        //return the chunks that is closet to the wanted chunkSize
        if (lowerChunkDiff < upperChunkDiff)
            return lowerChunkCount;
        if (upperChunkDiff < lowerChunkDiff)
            return upperChunkCount;
        return lowerChunkCount;
    }
    for (let i = 0; i < thisArg.length; i += chunkSize) {
        const part = thisArg.slice(i, i + chunkSize);
        result.push(part);
    }
    return result;
};
