declare type SortDirection = "ASC" | "DESC";
export {};
declare global {
    interface Array<T> {
        /**
         * Shorthand for sorting an array by a single comparable attribute. Additional options for sorting descending.
         *
         * Example
         * ```typescript
         * const lowestFirst = myArr.SortByArg(x => x.score);
         * const lowestFirst = myArr.SortByArg(x => x.score, "ASC");
         *
         * const highestFirst = myArr.SortByArg(x => x.score, "DESC");
         * ```
         */
        sortByAttr(callbackfn?: (value: T) => string | number, sortDirection?: SortDirection, thisArg?: any[]): T[];
    }
}
